# Crabatar

[![PyPI version](https://badge.fury.io/py/crabatar.svg)](https://badge.fury.io/py/crabatar)

Generate crab-themed avatars procedurally from usernames.

*Developed for [Crabber](https://github.com/jakeledoux/crabber/)*

## Installation

``` bash
pip install crabatar
```
